## Disclaimer

Some test data has been crawled from the internet. 
It is purely used to test SumMed under "real world" conditions.
If you feel like this violates content copyright, please contact us at hello@summed.org

Source:
- Files '_web_article_breast_cancer_prevention_xx.html_': [https://www.californiaprotons.com/breast-cancer/prevention-causes-risk-factors/]()
-  '_breast_cancer.pdf_: 
- '_breast_cancer_en.txt_': 
